function [ changed_profiles ] = get_changed_profiles( p_config, p_float )
%GET_CHANGED_PROFILES Loads the old profiles from the harddisk and compares them to the structure given in p_float.
%   Compares the old profiles that are saved on the harddisk with the given
%   float in p_float. Compares the profiles by using the
%   nemo.profile.compare function.
%
%   Parameters:
%   p_config:           The nemo configuration file.
%   p_float:            The nemo data where the old profiles will be
%                       compared with.
%
%   Returns:
%   changed_profiles:   Cell array containing the profiles that have
%                       changed.

%% Initialize return variables
changed_profiles = false;

%% Parameter check
if (~isstruct(p_config) || ~iscell(p_float))
    disp([ mfilename ': Please check your parameter!']);
    return;
end

%% Save the float to a temporary folder and load it afterwards
% this is because the comparison does not work with a float loaded from HDD
% and directly converted from SBD messages in RAM


%% Load old profiles

old_profiles = nemo.load.data( ...
    [ ...
        p_config.OUTPUT_FILES.output_path ...
        sprintf('%04d', p_float{1}.FLOAT_IDENTIFICATION.float_serial_number) ...
    ] ...
);

%% Compare them to the current ones

old_profiles = nemo.float.sort_by_profile_number(old_profiles);
p_float = nemo.float.sort_by_profile_number(p_float);
changed_profiles = {};

for i = 1:length(p_float)
    current_profile = p_float{i};
    old_profile = nemo.profile.find(old_profiles, current_profile.PROFILE_TECHNICAL_DATA.xmit_profile_number);
    if (isa(old_profile, 'logical') && ~old_profile) ...
            || ~nemo.profile.compare(old_profile, current_profile)
        changed_profiles{end + 1} = current_profile;
        continue;
    end
end


end

