function [ FromArray, Subject, Inline, AttachmentArray ] = extract( Message )
%EXTRACT Extracts basic information from the given message.
%   Extracts the message created by the javax.mail library.
%
%   Parameters:
%   Message:        The message to be extracted from.
%
%   Returns:
%   FromArray:          All senders addresses (usually just one)
%   Subject:            Subject of the message.
%   Inline:             The message body.
%   AttachmentArray:    All attachments of the message.

%% Initialize return variables
FromArray = false;
Subject = false;
Inline = '';
AttachmentArray = false;

%% Get from address
FromArray = Message.getFrom();
nFrom = FromArray.length;
% convert to matlab char
tmp = {};
for i = 1:nFrom
    tmp{i} = char(FromArray(i));
end
FromArray = tmp;
clear tmp;

%% Get subject
Subject = char(Message.getSubject());

%% Get inline text and attachments
MessageContent = Message.getContent();
if (~isempty(strfind(Message.getContentType, 'text/plain')))
    Inline = MessageContent;
    AttachmentArray = {};
    return
end
nBodies = MessageContent.getCount();
if (nBodies > 0)
    AttachmentArray = {};
end

for iBody = 0:nBodies - 1
    BodyPart = MessageContent.getBodyPart(iBody);
    if (BodyPart.isMimeType('text/plain') ...
        || BodyPart.isMimeType('text/html'))
        Inline = char(BodyPart.getContent());
    elseif (BodyPart.isMimeType('attachment') ...
            || BodyPart.isMimeType('application/x-zip-compressed'))
        AttachmentArray{iBody, 1} = BodyPart.getDataHandler.getName();
        AttachmentArray{iBody, 2} = BodyPart.getDataHandler.getInputStream();
    else
        disp([mfilename ': MimeType ' char(BodyPart.getContentType()) ' not supported!']);
    end
            
end


end

