function [ figure_id ] = create_south( p_config )
%CREATE_SOUTH Creates a template plot that can be used for a variety of plots that require Weddell Sea as location.
%
%   Returns:
%   figure_id:      Figure handle of the template.
%
%   Parameters:
%   p_config:       Global configuration file, load it using nemo.load.config().


%% Initialize return variable
figure_id = false;

%% Create template

% load additional files from disk
additional_content = nemo.load.additional_content(p_config);

% store loaded data (should be changed on long term thought)
Latitudes = additional_content.antarctic_latitudes;
Longitudes = additional_content.antarctic_longitudes;
ASI_Ice_Concentration = additional_content.antarctic_ice_concentration;
Z = additional_content.etopo_z;
refvec = additional_content.etopo_refvec;
moorings = additional_content.moorings;

clear additional_content

% initialize figure
figure_tmp = figure('Visible', 'off');
% prepare contour variables
[C1000,~] = contourm(Z,refvec,[-1000, -1000]);
[C2000,~] = contourm(Z,refvec,[-2000, -2000]);
[C3000,~] = contourm(Z,refvec,[-3000, -3000]);
%[C3500,~] = contourm(Z,refvec,[-3500 -3500]);
%[C4000,~] = contourm(Z,refvec,[-4000 -4000]);
close(figure_tmp);
clear figure_tmp Z refvec

%figure_id = figure();
figure_id = figure('Visible', 'Off');

%set(figure_id,'color',[1 1 1],'Position',get(0,'ScreenSize'));
%set(figure_id,'color',[1 1 1],'Position',[0, 0, 4000, 2250]);
worldmap(p_config.PLOT_OVERVIEW_SOUTH.latitude_limit, ...
    p_config.PLOT_OVERVIEW_SOUTH.longitude_limit);
load coast
plotm(lat,long,'k');

geoshow(Latitudes, Longitudes, ASI_Ice_Concentration, 'DisplayType','surface');
contourcmap('gray',10,'colorbar','off','location','horizontal', 'Visible', 'off');
nValues = 128;  %# The number of unique values in the colormap
%map = [linspace(0.5,1,nValues)' linspace(0.7,1,nValues)' ones(nValues,1)];  %'# 128-by-3 colormap
%colormap(map);
cmocean('ice', 'pivot', '-1');

ax_1000=plotm(C1000(2,:),C1000(1,:),'color',[0.2 0.6 .8]);
ax_2000=plotm(C2000(2,:),C2000(1,:),'color',[0 0 1]);
ax_3000= plotm(C3000(2,:),C3000(1,:),'color',[0.2 .4 0.8]);

%ax_3500= plotm(C3500(2,:),C3500(1,:),'color',[0.2 .2 0.8]);
%ax_4000= plotm(C4000(2,:),C4000(1,:),'color',[0.2 .0 0.8]);

%% make legend
%opengl hardware; % can only be used on pc with dedicated graphics

ax_deploy=plot3m(0,0,-1,'marker',p_config.PLOT_STYLE_SOUTH.deploy_marker,'markersize',p_config.PLOT_STYLE_SOUTH.deploy_markersize,'color', p_config.PLOT_STYLE_SOUTH.deploy_color,'linestyle','none');
ax_gps=plot3m(0,0,-1,'marker',p_config.PLOT_STYLE_SOUTH.gps_marker,'markersize',p_config.PLOT_STYLE_SOUTH.gps_markersize,'color',p_config.PLOT_STYLE_SOUTH.gps_color,'MarkerFaceColor', p_config.PLOT_STYLE_SOUTH.gps_color,'linestyle','none');
ax_gps_interpolated=plot3m(0,0,-1,'marker',p_config.PLOT_STYLE_SOUTH.gps_marker,'markersize',p_config.PLOT_STYLE_SOUTH.gps_markersize,'color',p_config.PLOT_STYLE_SOUTH.gps_color_interpolated,'MarkerFaceColor', p_config.PLOT_STYLE_SOUTH.gps_color_interpolated,'linestyle','none');
ax_last_transmittion=plot3m(0,0,-1,'marker',p_config.PLOT_STYLE_SOUTH.last_transmittion_marker,'markersize',p_config.PLOT_STYLE_SOUTH.last_transmittion_markersize,'color',p_config.PLOT_STYLE_SOUTH.last_transmittion_color,'MarkerFaceColor',p_config.PLOT_STYLE_SOUTH.last_transmittion_color,'linestyle','none');


legend([ax_deploy,ax_gps,ax_gps_interpolated,ax_last_transmittion,ax_1000,ax_2000,ax_3000],'Deployment positions','Best guess positions', 'Best guess positions (interpolated)', 'Last known position','-1000m','-2000m','-3000m');
%legend([ax_deploy,ax_gps,ax_gps_interpolated,ax_last_transmittion,ax_3000,ax_3500,ax_4000],'Deployment positions','Best guess positions', 'Best guess positions (interpolated)', 'Last known position','-3000m','-3500m','-4000m');

% cb=colorbar('southoutside');
% ylabel(cb, 'Sea ice concentration in %');

%% create title
text_figure_title = title('', 'position', [4.367541205137968 -5154159.006427274 99.99999999999999]);
set(text_figure_title,'interpreter','none','fontsize',14);

%% plot soso

earthradius = 3.4401e+003; % nm


if p_config.PLOT_OVERVIEW_SOUTH.show_moorings == 1
    
    if ~iscell(moorings)
        warning([mfilename ': Error loading moorings, skipping...']);
    else
        for o_moorings = 1:length(moorings)
            lat = moorings{o_moorings}.lat;
            lon = moorings{o_moorings}.lon;
            detection_radius = moorings{o_moorings}.detection_radius;
            if (~moorings{o_moorings}.hide_mooring)
                switch (p_config.PLOT_STYLE_SOUTH.moorings_display_format)
                    case 1
                        plot3m(lat,lon,140,'.c','markersize',24);
                        [latc,longc,] = scircle1(lat, lon, detection_radius,[],earthradius);
                        height=ones(numel(latc),1)*200;
                        plot3m(latc,longc,height,'color','k');
                    case 2
                        plot3m(lat, lon, 140, 'pg','markersize',8,'MarkerFaceColor','k');
                    case 3
                        plotm(lat, lon,'.c','markersize',24);
                        [latc,longc] = scircle1(lat, lon, detection_radius,[],earthradius);
                        height=ones(numel(latc),1)*200;
                        plot3m(latc,longc,height,'color','k');
                    case 4
                        plot3m(lat, lon, 140,'dr','markersize',6,'LineWidth',3);
                        [latc,longc] = scircle1(lat, lon, detection_radius,[],earthradius);
                        height=ones(numel(latc),1)*200;
                        plot3m(latc,longc,height,'color','k');
                    case 5
                        plot3m(lat, lon,140,'.','markersize',30,'color',[.8 .8 .8]);
                        [latc,longc] = scircle1(lat, lon, detection_radius,[],earthradius);
                        height=ones(numel(latc),1)*200;
                        plot3m(latc,longc,height,'color',[.8 .8 .8]);
                    case 6
                        plot3m(lat, lon,140,'ok','markersize',6,'linewidth',2.5);
                        [latc,longc] = scircle1(lat, lon, detection_radius,[],earthradius);
                        height=ones(numel(latc),1)*200;
                        plot3m(latc,longc,height,'color','k');
                    case 7
                        plot3m(lat, lon,140,'og','markersize',6,'linewidth',2.5);
                        [latc,longc] = scircle1(lat, lon, detection_radius,[],earthradius);
                        geoshow(latc,longc,'color','k');
                    case 8
                        plot3m(lat, lon,140,'k*','markersize',8);
                    case 9
                        plot3m(lat, lon,140,'.','markersize',30,'color',[.8 .8 .8]);
                        [latc,longc] = scircle1(lat, lon, detection_radius,[],earthradius);
                        height=ones(numel(latc),1)*200;
                        plot3m(latc,longc,height,'color',[0 0 0]);
                    otherwise
                        plot3m(lat, lon,140,'.','markersize',30,'color',[.8 .8 .8]);
                        [latc,longc] = scircle1(lat, lon, detection_radius,[],earthradius);
                        height=ones(numel(latc),1)*200;
                        plot3m(latc,longc,height,'color',[0 0 0]);
                end
                
                if moorings{o_moorings}.show_name
                    h2=textm(lat, lon,140, moorings{o_moorings}.name);
                    set(h2,'Color','k', 'FontSize',6,'FontWeight','bold','HorizontalAlignment','center');
                end
                
            end
        end
        clear lat lon detection_radius
    end
    
end 

end

