function [ boolean ] = positions_differ_by( p_profile, p_distance )
%POSITIONS_DIFFER_BY Checks if gps and iridium coordinates differ by given distance.
%
%   Returns: True if the distance exceeds p_distance [km].
%
%   Parameters:
%   p_profile:          The nemo profile that is being checked.
%   p_distance:         The maximum distance that is being accepted.

%% Initializing return variables
boolean = false;

%% Parameter check

if (~isstruct(p_profile))
    disp([mfilename ': Wrong parameter. Please check your input. Returning false!']);
end

%% Check coordinates

if (~nemo.profile.has_gps(p_profile) || ~nemo.profile.has_iridium(p_profile))
    return;
end

% get distance in between
difference = deg2km( ...
    distance('gc', ... % convert to km for easier handling
        [p_profile.SURFACE_GPS_DATA(14), p_profile.SURFACE_GPS_DATA(15)], ...
        [p_profile.IRIDIUM_DATA(1), p_profile.IRIDIUM_DATA(2)] ...
    ) ...
);

if (difference > p_distance)
    boolean = true;
end

end

